==> v0.0.2.tar.gz: dotsort/src/DotSort/Game.cpp <==
#include <DotSort/Game.hpp>

#include <SFML/System/Clock.hpp>

#include <SFML/Graphics/RenderWindow.hpp>

#include <SFML/Window/Event.hpp>
#include <SFML/Window/Keyboard.hpp>

/* Non game stuff */

#include <cstdint>
#include <vector>

#include <SFML/Graphics.hpp>

#include <iostream> // DEBUG

Game::Game() :
	window(new sf::RenderWindow(sf::VideoMode::getDesktopMode(), this->name, sf::Style::Fullscreen))
{
	this->window->setFramerateLimit(30);

	/* Non game stuff */
	this->tubeSet = new TubeSet();

	this->view = new View(this->tubeSet->tubeSize, this->tubeSet->tubeCount, this->tubeSet->ldots);
}

Game::~Game()
{
	this->window->close();
	delete this->window;
}

void Game::run()
{
	// To minimize gap between creation and run()
	// Is it important?
	this->clock.restart();

	while(!this->quit)
	{
		this->update();
		this->processEvents();
		this->draw();
	}
}

void Game::draw()
{
	this->window->clear(sf::Color::White);
	this->updateView();
	this->window->draw(*this->view);
	this->window->display();
}

void Game::update()
{
}

void Game::processEvents()
{
	sf::Event event;
	while (this->window->pollEvent(event))
	{
		if(event.type == sf::Event::Closed)
		{
			this->quit = true;
		}
		else if(event.type == sf::Event::KeyPressed)
		{
			if(event.key.code == sf::Keyboard::Escape)
			{
				this->quit = true;
			}
		}
		else if(event.type == sf::Event::MouseButtonPressed)
		{
			std::optional<uint8_t> tubeIndex = this->view->getTubeIndex(event);
			if(tubeIndex)
			{
				this->onTubeClick(tubeIndex.value());
			}
		}
	}
}

void Game::onTubeClick(uint8_t index)
{
	if(this->selectedTube)
	{
		if(this->selectedTube == index)
		{
			this->selectedTube = std::nullopt;
		}
		else if(this->tubeSet->isPossibleStep(*this->selectedTube, index))
		{
			this->tubeSet->doStep(*this->selectedTube, index);
			this->selectedTube = std::nullopt;
		}
	}
	else
	{
		this->selectedTube = index;
	}
}

void Game::updateView() const
{
	for(uint8_t i = 0; i < this->tubeSet->tubeCount; ++i)
	{
		this->view->updateTube(i, this->tubeSet->getTube(i));
	}
}

==> v0.0.5.tar.gz: dotsort/src/DotSort/Game.cpp <==
// SPDX-License-Identifier: GPL-2.0-or-later
// Copyright (c) 2023 Yevhen Babiichuk (DustDFG)

#include <DotSort/Game.hpp>

#include <SFML/System/Clock.hpp>

#include <SFML/Graphics/RenderWindow.hpp>

#include <SFML/Window/Event.hpp>
#include <SFML/Window/Keyboard.hpp>

/* Non game stuff */

#include <cstdint>
#include <vector>

#include <SFML/Graphics.hpp>

#include <Abracadabra/VectorTubeSetBuilder.hpp>

#include <iostream> // DEBUG

Game::Game() :
	window(new sf::RenderWindow(sf::VideoMode::getDesktopMode(), this->name, sf::Style::Fullscreen))
{
	this->window->setFramerateLimit(30);

	/* Non game stuff */
	std::vector<std::vector<uint8_t>> ldots = {
		{2, 2, 1, 3},
		{1, 0, 3, 2},
		{3, 0, 1, 0},
		{0, 1},
		{2, 3},
		{},
		{}
	};

	VectorTubeSetBuilder builder(4, 7, ldots);
	this->tubeSet = builder();

	this->view = new View::View(this->tubeSet->tubeSize, this->tubeSet->tubeCount);
}

Game::~Game()
{
	this->window->close();
	delete this->window;
}

void Game::run()
{
	// To minimize gap between creation and run()
	// Is it important?
	this->clock.restart();

	while(!this->quit)
	{
		this->update();
		this->processEvents();
		this->draw();
	}
}

void Game::draw()
{
	this->window->clear(sf::Color::White);
	this->updateView();
	this->window->draw(*this->view);
	this->window->display();
}

void Game::update()
{
}

void Game::processEvents()
{
	sf::Event event;
	while (this->window->pollEvent(event))
	{
		if(event.type == sf::Event::Closed)
		{
			this->quit = true;
		}
		else if(event.type == sf::Event::KeyPressed)
		{
			if(event.key.code == sf::Keyboard::Escape)
			{
				this->quit = true;
			}
		}
		else if(event.type == sf::Event::MouseButtonPressed)
		{
			std::optional<uint8_t> tubeIndex = this->view->getTubeIndex(event);
			if(tubeIndex)
			{
				this->onTubeClick(tubeIndex.value());
			}
			else
			{
				this->selectedTube = this->selectedTube = std::nullopt;;
			}
		}
	}
}

void Game::onTubeClick(uint8_t index)
{
	if(this->selectedTube)
	{
		if(this->selectedTube == index)
		{
			this->selectedTube = std::nullopt;
		}
		else if(this->tubeSet->isPossibleStep(*this->selectedTube, index))
		{
			this->tubeSet->doStep(*this->selectedTube, index);
			this->selectedTube = std::nullopt;
		}
	}
	else
	{
		this->selectedTube = index;
	}
}

void Game::updateView() const
{
	for(uint8_t i = 0; i < this->tubeSet->tubeCount; ++i)
	{
		this->view->updateTube(i, this->tubeSet->getTube(i));
	}
}
